# Welcome to xopr

[![Tests](https://github.com/thomasteisberg/xopr/actions/workflows/test.yml/badge.svg)](https://github.com/thomasteisberg/xopr/actions/workflows/test.yml)
[![Documentation](https://github.com/thomasteisberg/xopr/actions/workflows/docs.yml/badge.svg)](https://github.com/thomasteisberg/xopr/actions/workflows/docs.yml)
[![PyPI Version](https://img.shields.io/pypi/v/xopr.svg)](https://pypi.org/project/xopr/)
[![License](https://img.shields.io/github/license/thomasteisberg/xopr.svg)](LICENSE)

**Documentation:** [![Jupyter Book Badge](https://jupyterbook.org/badge.svg)](https://www.thomasteisberg.com/xopr/)

**Code Coverage:** [Coverage Report](https://thomasteisberg.github.io/xopr/coverage/)

**Contributor Code of Conduct:** [![Code of Conduct](https://img.shields.io/badge/Contributor%20Covenant-v2.0%20adopted-ff69b4.svg)](CODE_OF_CONDUCT.md)

xopr is a Python library designed to make accessing [Open Polar Radar's](https://ops.cresis.ku.edu/) data archives easy, scalable, and reproducible; see [here for current data availibility](https://www.thomasteisberg.com/xopr/polar-maps/) within xopr..

**xopr is a work in progress! The API may evolve as we continue towards a stable 1.0 release.**

We welcome your feedback and contributions. If you run into problems or have ideas for how this could be better, please consider [opening an issue](https://github.com/thomasteisberg/xopr/issues/new/choose). We also welcome pull requests!

## Get started

Check out our [documentation](https://www.thomasteisberg.com/xopr/) to get started. The documentation includes example notebooks to show you the core functions.

## License

This library was originally written by Thomas Teisberg and Shane Grigsby. It is open source and licensed udner the [MIT License](./LICENSE).
